uim.codec.writer.encoder API documentation
Description: Encoder classes This package contains all encoders for the Universal Ink Model: …

# Module `uim.codec.writer.encoder`

# Encoder classes

This package contains all encoders for the Universal Ink Model:

- Version 3.1.0

Expand source code

    # -*- coding: utf-8 -*-
    """
    Encoder classes
    ===============
    This package contains all encoders for the Universal Ink Model:

    - Version 3.1.0
    """
    __all__ = ['encoder_3_1_0', 'base']

    from uim.codec.writer.encoder import base
    from uim.codec.writer.encoder import encoder_3_1_0

## Sub-modules

`uim.codec.writer.encoder.base`
`uim.codec.writer.encoder.encoder_3_1_0`